@@ -1,19 +1,9 @@
 /*
- * Copyright (C) 2013 - Julien Desfossez <jdesfossez@efficios.com>
- *                      David Goulet <dgoulet@efficios.com>
+ * Copyright (C) 2013 Julien Desfossez <jdesfossez@efficios.com>
+ * Copyright (C) 2013 David Goulet <dgoulet@efficios.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License, version 2 only,
- * as published by the Free Software Foundation.
+ * SPDX-License-Identifier: GPL-2.0-only
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
- * more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #define _LGPL_SOURCE
@@ -273,17 +263,20 @@ int consumer_metadata_cache_flushed(struct lttng_consumer_channel *channel,
 		pthread_mutex_lock(&channel->lock);
 	}
 	pthread_mutex_lock(&channel->timer_lock);
-	pthread_mutex_lock(&channel->metadata_cache->lock);
-
 	metadata_stream = channel->metadata_stream;
-
 	if (!metadata_stream) {
 		/*
 		 * Having no metadata stream means the channel is being destroyed so there
 		 * is no cache to flush anymore.
 		 */
 		ret = 0;
-	} else if (metadata_stream->ust_metadata_pushed >= offset) {
+		goto end_unlock_channel;
+	}
+
+	pthread_mutex_lock(&metadata_stream->lock);
+	pthread_mutex_lock(&channel->metadata_cache->lock);
+
+	if (metadata_stream->ust_metadata_pushed >= offset) {
 		ret = 0;
 	} else if (channel->metadata_stream->endpoint_status !=
 			CONSUMER_ENDPOINT_ACTIVE) {
@@ -295,6 +288,8 @@ int consumer_metadata_cache_flushed(struct lttng_consumer_channel *channel,
 	}
 
 	pthread_mutex_unlock(&channel->metadata_cache->lock);
+	pthread_mutex_unlock(&metadata_stream->lock);
+end_unlock_channel:
 	pthread_mutex_unlock(&channel->timer_lock);
 	if (!timer) {
 		pthread_mutex_unlock(&channel->lock);
